function zf=zeropadf(f)
%ZEROPADF  Applies zero padding to vector/scalar fields.
%   ZF = ZEROPADF(F) applies zero padding to vector/scalar field(s) F, such
%   that ZF is a square field of side given by the largest dimension of F.
%   It adds borders of zeros on each sides of the initial rectangle.
%
%   This function is useful with SPEC2F, which requires square fields
%
%   See also TRUNCF, EXTRACTF, ROTATEF, RESIZEF, FLIPF, SHIFTF, REMAPF.


%   F. Moisy, moisy_at_fast.u-psud.fr
%   Revision: 1.00,  Date: 2018/07/02
%   This function is part of the PIVMat Toolbox


% History:
% 2018/07/02: v1.00, first version.


if (ischar(f) || iscellstr(f))
    f=loadvec(f);
end

zf = f;

nx = length(f(1).x);  ny = length(f(1).y);
if nx ~= ny
    dx = f(1).x(2)-f(1).x(1);
    dy = f(1).y(2)-f(1).y(1);
    for i=1:length(f)
        if nx>ny
            zf(i).y = zf(i).y(1) + dy*(0:(nx-1));
            switch numcompfield(f(i))
                case 1
                    zf(i).w = padarray(f(i).w, [0 nx-ny],'post');
                case 2
                    zf(i).vx = padarray(f(i).vx, [0 nx-ny],'post');
                    zf(i).vy = padarray(f(i).vy, [0 nx-ny],'post');
                case 3
                    zf(i).vx = padarray(f(i).vx, [0 nx-ny],'post');
                    zf(i).vy = padarray(f(i).vy, [0 nx-ny],'post');
                    zf(i).vz = padarray(f(i).vz, [0 nx-ny],'post');
            end
        else
            zf(i).x = zf(i).x(1) + dx*(0:(ny-1));
            switch numcompfield(f(i))
                case 1
                    zf(i).w = padarray(f(i).w, [ny-nx 0],'post');
                case 2
                    zf(i).vx = padarray(f(i).vx, [ny-nx 0],'post');
                    zf(i).vy = padarray(f(i).vy, [ny-nx 0],'post');
                case 3
                    zf(i).vx = padarray(f(i).vx, [ny-nx 0],'post');
                    zf(i).vy = padarray(f(i).vy, [ny-nx 0],'post');
                    zf(i).vz = padarray(f(i).vz, [ny-nx 0],'post');
            end
        end
        zf(i).history = {{f(i).history}' 'zeropadf(ans)'}';
    end
end

if nargout==0
    showf(zf);
    clear zf
end
